@@ -12,7 +12,6 @@ import numpy as np
 from PIL import Image
 from skimage import img_as_ubyte
 from skimage.measure import regionprops
-from pycocotools import mask
 
 from .utils import get_semantic_bitmap
 
@@ -120,7 +119,13 @@ def get_bbox(binary_mask):
         return False
 
 
-def export_coco_instance(dataset, export_folder):
+def export_coco_instance(dataset, export_folder, **kwargs):
+    try:
+        from pycocotools import mask as pctmask
+    except ImportError:
+        print('Please install pycocotools first: pip install pycocotools. Or on Windows: pip install pycocotools-windows')
+        return
+
     # Create export folder
     # export_folder = os.path.join(export_folder, dataset.dataset_identifier, dataset.release['name'])
     os.makedirs(export_folder, exist_ok=True)
@@ -198,7 +203,7 @@ def export_coco_instance(dataset, export_folder):
                     
                 y0, x0, y1, x1 = bbox
                 # rle = mask.encode(np.asfortranarray(instance_mask))
-                rle = mask.encode(np.array(instance_mask[:,:,None], dtype=np.uint8, order='F'))[0] # https://github.com/matterport/Mask_RCNN/issues/387#issuecomment-522671380
+                rle = pctmask.encode(np.array(instance_mask[:,:,None], dtype=np.uint8, order='F'))[0] # https://github.com/matterport/Mask_RCNN/issues/387#issuecomment-522671380
         #         instance_mask_crop = instance_mask[y0:y1, x0:x1]
         #         rle = mask.encode(np.asfortranarray(instance_mask_crop))
         #         plt.imshow(instance_mask_crop)
@@ -252,7 +257,7 @@ def export_coco_instance(dataset, export_folder):
 
 
 
-def export_coco_panoptic(dataset, export_folder):
+def export_coco_panoptic(dataset, export_folder, **kwargs):
     # Create export folder
     # export_folder = os.path.join(export_folder, dataset.dataset_identifier, dataset.release['name'])
     os.makedirs(export_folder, exist_ok=True)
@@ -393,7 +398,7 @@ def export_coco_panoptic(dataset, export_folder):
     return file_name, dataset.image_dir
 
 
-def export_image(dataset, export_folder, export_format, id_increment):
+def export_image(dataset, export_folder, export_format, id_increment, **kwargs):
     # Create export folder
     # export_folder = os.path.join(export_folder, dataset.dataset_identifier, dataset.release['name'])
     os.makedirs(export_folder, exist_ok=True)
@@ -456,7 +461,7 @@ def export_image(dataset, export_folder, export_format, id_increment):
     return dataset.image_dir
 
 
-def export_yolo(dataset, export_folder):
+def export_yolo(dataset, export_folder, **kwargs):
     if dataset.task_type not in ['vector', 'bboxes']:
         print('You can only export bounding box datasets to YOLO format.')
         return
@@ -469,8 +474,13 @@ def export_yolo(dataset, export_folder):
 
         if 'annotations' in sample and sample['annotations'] is not None and len(sample['annotations']) > 0:
             image_name = os.path.splitext(os.path.basename(sample['name']))[0]
-            image_width = sample['image'].width
-            image_height = sample['image'].height
+
+            if 'image_width' in kwargs and 'image_height' in kwargs:
+                image_width = kwargs['image_width']
+                image_height = kwargs['image_height']
+            else:
+                image_width = sample['image'].width
+                image_height = sample['image'].height
             
             file_name = '{}/{}.txt'.format(dataset.image_dir, image_name)
     #         print(file_name)       
